@@ -48,6 +48,9 @@ class ProxyConnection(Connection):
         self.real_ip = None
         self.range_from = None
         self.ignore_auth_cache = False
+        self.tenant_name = None
+        if kwargs.get('auth_version') == "2.0":
+            self.tenant_name = kwargs['tenant_name']
         super(ProxyConnection, self).__init__(*args, **kwargs)
 
     def http_connection(self):
@@ -77,7 +80,8 @@ class ProxyConnection(Connection):
     def get_auth(self):
         """Perform the authentication using a token cache if memcache is available"""
         if self.memcache:
-            key = "tk%s" % md5("%s%s%s" % (self.authurl, self.user, self.key)).hexdigest()
+            tenant_name = self.tenant_name or "-"
+            key = "tk%s" % md5("%s%s%s%s" % (self.authurl, self.user, tenant_name, self.key)).hexdigest()
             cache = self.memcache.get(key)
             if not cache or self.ignore_auth_cache:
                 logging.debug("token cache miss, key=%s" % key)
@@ -378,9 +382,10 @@ class ListDirCache(object):
 
     def key(self, index):
         """Returns a key for a user distributed cache."""
-        logging.debug("cache key for %r" % [self.cffs.authurl, self.cffs.username, index])
+        tenant_name = self.cffs.tenant_name or "-"
+        logging.debug("cache key for %r" % [self.cffs.authurl, self.cffs.username, tenant_name, index])
         if not hasattr(self, "_key_base"):
-            self._key_base = md5("%s%s" % (self.cffs.authurl, self.cffs.username)).hexdigest()
+            self._key_base = md5("%s%s%s" % (self.cffs.authurl, self.cffs.username, tenant_name)).hexdigest()
         return "%s-%s" % (self._key_base, md5(smart_str(index)).hexdigest())
 
     def flush(self, path=None):
@@ -632,12 +637,11 @@ class ObjectStorageFS(object):
             raise ClientException("username/password required", http_status=401)
 
         kwargs = dict(authurl=self.authurl, auth_version="1.0")
+        tenant_name = None
 
         if self.keystone:
             if self.keystone['tenant_separator'] in username:
                 tenant_name, username = username.split(self.keystone['tenant_separator'], 1)
-            else:
-                tenant_name = None
 
             logging.debug("keystone authurl=%r username=%r tenant_name=%r conf=%r" % (self.authurl, username, tenant_name, self.keystone))
 
@@ -659,6 +663,7 @@ class ObjectStorageFS(object):
         self.conn.http_conn = None
         # now we are authenticated and we have an username
         self.username = username
+        self.tenant_name = tenant_name
 
     def close(self):
         """Dummy function which does nothing - no need to close"""
